==> gtkmathview_0.7.0.orig.tar.gz: gtkmathview-0.7.0/src/engine/boxml/BoxMLboxElement.cc <==
// Copyright (C) 2000-2003, Luca Padovani <luca.padovani@cs.unibo.it>.
//
// This file is part of GtkMathView, a Gtk widget for MathML.
// 
// GtkMathView is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// GtkMathView is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with GtkMathView; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// For details, see the GtkMathView World-Wide-Web page,
// http://helm.cs.unibo.it/mml-widget, or send a mail to
// <luca.padovani@cs.unibo.it>

#include <config.h>

#include "BoxMLNamespaceContext.hh"
#include "BoxMLboxElement.hh"
#include "FormattingContext.hh"
#include "BoxGraphicDevice.hh"

BoxMLboxElement::BoxMLboxElement(const SmartPtr<BoxMLNamespaceContext>& context)
  : BoxMLBinContainerElement(context)
{ }

BoxMLboxElement::~BoxMLboxElement()
{ }

AreaRef
BoxMLboxElement::format(FormattingContext& ctxt)
{
  if (dirtyLayout())
    {
      ctxt.push(this);
      ctxt.setMathMode(false);
      if (SmartPtr<BoxMLElement> child = getChild())
	setArea(ctxt.BGD()->wrapper(ctxt, child->format(ctxt)));
      ctxt.pop();
      resetDirtyLayout();
    }

  return getArea();
}

==> gtkmathview_0.7.7.orig.tar.gz: gtkmathview-0.7.7/src/engine/boxml/BoxMLboxElement.cc <==
// Copyright (C) 2000-2003, Luca Padovani <luca.padovani@cs.unibo.it>.
//
// This file is part of GtkMathView, a Gtk widget for MathML.
// 
// GtkMathView is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// GtkMathView is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with GtkMathView; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// For details, see the GtkMathView World-Wide-Web page,
// http://helm.cs.unibo.it/mml-widget, or send a mail to
// <luca.padovani@cs.unibo.it>

#include <config.h>

#include "BoxMLNamespaceContext.hh"
#include "BoxMLboxElement.hh"
#include "FormattingContext.hh"
#include "BoxGraphicDevice.hh"

BoxMLboxElement::BoxMLboxElement(const SmartPtr<BoxMLNamespaceContext>& context)
  : BoxMLBinContainerElement(context)
{ }

BoxMLboxElement::~BoxMLboxElement()
{ }

AreaRef
BoxMLboxElement::format(FormattingContext& ctxt)
{
  if (dirtyLayout())
    {
      ctxt.push(this);
      ctxt.setMathMode(false);
      if (SmartPtr<BoxMLElement> child = getChild())
	{
	  child->format(ctxt);
	  setMaxArea(ctxt.BGD()->wrapper(ctxt, child->getMaxArea()));
	  setArea(ctxt.BGD()->wrapper(ctxt, child->getArea()));
	}
      ctxt.pop();
      resetDirtyLayout();
    }

  return getArea();
}
